ActivityEvent class

Represents an activity event detected on the phone.

Constructors

ActivityEvent(ActivityType type, int confidence, [DateTime? timeStamp])
ActivityEvent.unknown()
factory

Properties

confidence int
The confidence of the detection in percent (0-100).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeStamp DateTime
The timestamp of the detection, as reported by the platform.
final
type ActivityType
The type of activity.
final
typeString String
The type of activity as a String.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited